==> jc-1.4.0.tar.gz: java/text/SimpleDateFormat__24CompiledField.h <==
// class java.text.SimpleDateFormat$CompiledField

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a0219dae9b78dc6b java_text_SimpleDateFormat__24CompiledField

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_SimpleDateFormat__24CompiledField_H_
#define _JC_java_text_SimpleDateFormat__24CompiledField_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_SimpleDateFormat$object;
struct _jc_java_text_SimpleDateFormat__24CompiledField$object;

// Typedefs
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$sub_refs	_jc_java_text_SimpleDateFormat__24CompiledField$sub_refs;
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$sub_nonrefs	_jc_java_text_SimpleDateFormat__24CompiledField$sub_nonrefs;
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$refs	_jc_java_text_SimpleDateFormat__24CompiledField$refs;
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$nonrefs	_jc_java_text_SimpleDateFormat__24CompiledField$nonrefs;
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$object	_jc_java_text_SimpleDateFormat__24CompiledField$object;

typedef const struct _jc_java_text_SimpleDateFormat__24CompiledField$vmethods	_jc_java_text_SimpleDateFormat__24CompiledField$vmethods;
typedef const struct _jc_java_text_SimpleDateFormat__24CompiledField$vtable	_jc_java_text_SimpleDateFormat__24CompiledField$vtable;
typedef const struct _jc_java_text_SimpleDateFormat__24CompiledField$vtype	_jc_java_text_SimpleDateFormat__24CompiledField$vtype;

// Constructors
extern void _jc_java_text_SimpleDateFormat__24CompiledField$method$_init$c075e5dd050f915c(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *, struct _jc_java_text_SimpleDateFormat$object *, jint, jint, jchar);

// Virtual methods
extern jchar _jc_java_text_SimpleDateFormat__24CompiledField$method$getCharacter$359e15f5aad02c9b(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
extern jint _jc_java_text_SimpleDateFormat__24CompiledField$method$getField$fe750df026150d0f(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
extern jint _jc_java_text_SimpleDateFormat__24CompiledField$method$getSize$82f1d9ee1217ad91(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
extern struct _jc_java_lang_String$object *_jc_java_text_SimpleDateFormat__24CompiledField$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_SimpleDateFormat__24CompiledField$method_info$getCharacter$359e15f5aad02c9b;
extern _jc_method _jc_java_text_SimpleDateFormat__24CompiledField$method_info$getField$fe750df026150d0f;
extern _jc_method _jc_java_text_SimpleDateFormat__24CompiledField$method_info$getSize$82f1d9ee1217ad91;
extern _jc_method _jc_java_text_SimpleDateFormat__24CompiledField$method_info$toString$7ea43b33b80a3070;

// Static methods
extern jint _jc_java_text_SimpleDateFormat__24CompiledField$method$access__240$cb31fcabdb604df7(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
extern jint _jc_java_text_SimpleDateFormat__24CompiledField$method$access__241$9d44a57d1b23fa50(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
extern void _jc_java_text_SimpleDateFormat__24CompiledField$method$access__242$ddf0c47e9a1cb3e4(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *, jint);

// Virtual methods structure
struct _jc_java_text_SimpleDateFormat__24CompiledField$vmethods {
	jchar	(*getCharacter$359e15f5aad02c9b)(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
	jint	(*getField$fe750df026150d0f)(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
	jint	(*getSize$82f1d9ee1217ad91)(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *);
};

// Vtable
struct _jc_java_text_SimpleDateFormat__24CompiledField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_SimpleDateFormat__24CompiledField$vmethods	java_text_SimpleDateFormat__24CompiledField;
};

// Vtype
struct _jc_java_text_SimpleDateFormat__24CompiledField$vtype {
	_jc_type			type;
	_jc_java_text_SimpleDateFormat__24CompiledField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_SimpleDateFormat__24CompiledField$sub_refs {
	struct _jc_java_text_SimpleDateFormat$object	*this;
};

// Reference instance fields (object)
struct _jc_java_text_SimpleDateFormat__24CompiledField$refs {
    _jc_java_text_SimpleDateFormat__24CompiledField$sub_refs	java_text_SimpleDateFormat__24CompiledField;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_SimpleDateFormat__24CompiledField$sub_nonrefs {
	jint	field;
	jint	size;
	jchar	character;
};

// Non-reference instance fields (object)
struct _jc_java_text_SimpleDateFormat__24CompiledField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_SimpleDateFormat__24CompiledField$sub_nonrefs	java_text_SimpleDateFormat__24CompiledField;
};

// Object instance structure
struct _jc_java_text_SimpleDateFormat__24CompiledField$object {
	_jc_java_text_SimpleDateFormat__24CompiledField$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_SimpleDateFormat__24CompiledField$vtype	*vtype;
	_jc_java_text_SimpleDateFormat__24CompiledField$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_SimpleDateFormat__24CompiledField$vtype _jc_java_text_SimpleDateFormat__24CompiledField$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_SimpleDateFormat__24CompiledField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_SimpleDateFormat__24CompiledField$class_object;

#endif	/* _JC_java_text_SimpleDateFormat__24CompiledField_H_ */

==> jc-1.4.5.tar.gz: java/text/SimpleDateFormat__24CompiledField.h <==
// class java.text.SimpleDateFormat$CompiledField

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a0219dae9b78dc6b java_text_SimpleDateFormat__24CompiledField

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_SimpleDateFormat__24CompiledField_H_
#define _JC_java_text_SimpleDateFormat__24CompiledField_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_SimpleDateFormat$object;
struct _jc_java_text_SimpleDateFormat__24CompiledField$object;

// Typedefs
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$sub_refs	_jc_java_text_SimpleDateFormat__24CompiledField$sub_refs;
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$sub_nonrefs	_jc_java_text_SimpleDateFormat__24CompiledField$sub_nonrefs;
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$refs	_jc_java_text_SimpleDateFormat__24CompiledField$refs;
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$nonrefs	_jc_java_text_SimpleDateFormat__24CompiledField$nonrefs;
typedef struct _jc_java_text_SimpleDateFormat__24CompiledField$object	_jc_java_text_SimpleDateFormat__24CompiledField$object;

typedef const struct _jc_java_text_SimpleDateFormat__24CompiledField$vmethods	_jc_java_text_SimpleDateFormat__24CompiledField$vmethods;
typedef const struct _jc_java_text_SimpleDateFormat__24CompiledField$vtable	_jc_java_text_SimpleDateFormat__24CompiledField$vtable;
typedef const struct _jc_java_text_SimpleDateFormat__24CompiledField$vtype	_jc_java_text_SimpleDateFormat__24CompiledField$vtype;

// Constructors
extern void _jc_java_text_SimpleDateFormat__24CompiledField$method$_init$c075e5dd050f915c(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *, struct _jc_java_text_SimpleDateFormat$object *, jint, jint, jchar) _JC_JCNI_ATTR;

// Virtual methods
extern jchar _jc_java_text_SimpleDateFormat__24CompiledField$method$getCharacter$359e15f5aad02c9b(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
extern jint _jc_java_text_SimpleDateFormat__24CompiledField$method$getField$fe750df026150d0f(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
extern jint _jc_java_text_SimpleDateFormat__24CompiledField$method$getSize$82f1d9ee1217ad91(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_text_SimpleDateFormat__24CompiledField$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_SimpleDateFormat__24CompiledField$method_info$getCharacter$359e15f5aad02c9b;
extern _jc_method _jc_java_text_SimpleDateFormat__24CompiledField$method_info$getField$fe750df026150d0f;
extern _jc_method _jc_java_text_SimpleDateFormat__24CompiledField$method_info$getSize$82f1d9ee1217ad91;
extern _jc_method _jc_java_text_SimpleDateFormat__24CompiledField$method_info$toString$7ea43b33b80a3070;

// Static methods
extern jint _jc_java_text_SimpleDateFormat__24CompiledField$method$access__240$cb31fcabdb604df7(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
extern jint _jc_java_text_SimpleDateFormat__24CompiledField$method$access__241$9d44a57d1b23fa50(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
extern void _jc_java_text_SimpleDateFormat__24CompiledField$method$access__242$ddf0c47e9a1cb3e4(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_text_SimpleDateFormat__24CompiledField$vmethods {
	jchar	(*getCharacter$359e15f5aad02c9b)(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
	jint	(*getField$fe750df026150d0f)(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
	jint	(*getSize$82f1d9ee1217ad91)(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_text_SimpleDateFormat__24CompiledField$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_SimpleDateFormat__24CompiledField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_SimpleDateFormat__24CompiledField$vmethods	java_text_SimpleDateFormat__24CompiledField;
};

// Vtype
struct _jc_java_text_SimpleDateFormat__24CompiledField$vtype {
	_jc_type			type;
	_jc_java_text_SimpleDateFormat__24CompiledField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_SimpleDateFormat__24CompiledField$sub_refs {
	struct _jc_java_text_SimpleDateFormat$object	*this;
};

// Reference instance fields (object)
struct _jc_java_text_SimpleDateFormat__24CompiledField$refs {
    _jc_java_text_SimpleDateFormat__24CompiledField$sub_refs	java_text_SimpleDateFormat__24CompiledField;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_SimpleDateFormat__24CompiledField$sub_nonrefs {
	jint	field;
	jint	size;
	jchar	character;
};

// Non-reference instance fields (object)
struct _jc_java_text_SimpleDateFormat__24CompiledField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_SimpleDateFormat__24CompiledField$sub_nonrefs	java_text_SimpleDateFormat__24CompiledField;
};

// Object instance structure
struct _jc_java_text_SimpleDateFormat__24CompiledField$object {
	_jc_java_text_SimpleDateFormat__24CompiledField$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_SimpleDateFormat__24CompiledField$vtype	*vtype;
	_jc_java_text_SimpleDateFormat__24CompiledField$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_SimpleDateFormat__24CompiledField$vtype _jc_java_text_SimpleDateFormat__24CompiledField$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_SimpleDateFormat__24CompiledField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_SimpleDateFormat__24CompiledField$class_object;

#endif	/* _JC_java_text_SimpleDateFormat__24CompiledField_H_ */
